package Number::Phone::JP::Table::Q2;

use strict;
use warnings;

our $VERSION = '0.20190104';

# Table last modified: 2019-01-04
our %TEL_TABLE = (
    # Pref => q<Assoc-Pref-Regex>,
    990 => '(?:5(?:1[36]|04|25)\d{3})',
);

1;
__END__
